==> bytedesk_kefu-0.0.1.tar.gz: lib/repositories/user_repository.dart <==
import 'dart:async';
// import 'package:google_sign_in/google_sign_in.dart';
import 'package:bytedesk_kefu/model/codeResult.dart';
import 'package:bytedesk_kefu/model/jsonResult.dart';
import 'package:bytedesk_kefu/model/user.dart';
import 'package:bytedesk_kefu/http/http_api_client.dart';
import 'package:bytedesk_kefu/model/oauth.dart';
// import 'package:meta/meta.dart';

class UserRepository {
  
  final HttpApiClient httpApiClient = HttpApiClient();

  UserRepository();

  Future<OAuth> login(String username, String password) {
    print("login username $username, password $password");
    return httpApiClient.oauth(username, password);
  }

  Future<OAuth> smsOAuth(String mobile, String code) async {
    print("user_repository smsOAuth");
    return await httpApiClient.smsOAuth(mobile, code);
  }

  Future<JsonResult> register(String mobile, String password) async {
    print("user_repository register");
    return await httpApiClient.register(mobile, password);
  }

  Future<JsonResult> changePassword(String mobile, String password) async {
    print("user_repository change");
    return await httpApiClient.changePassword(mobile, password);
  }

  Future<CodeResult> requestCode(String mobile) async {
    print("user_repository requestCode");
    return await httpApiClient.requestCode(mobile);
  }

  Future<String> upload(String filePath) async {
    return await httpApiClient.upload(filePath);
  }

  Future<User> updateAvatar(String avatar) async {
    return await httpApiClient.updateAvatar(avatar);
  }

  Future<User> updateNickname(String nickname) async {
    return await httpApiClient.updateNickname(nickname);
  }

  Future<User> updateDescription(String description) async {
    return await httpApiClient.updateDescription(description);
  }

  Future<void> logout() async {
    print("user_repository logout");
    return Future.wait([httpApiClient.logout()]);
  }

  // Future<bool> isLogin() async {
  //   print("user_repository isSignedIn");
  //   // final currentUser = await httpApiClient.currentUser();
  //   // return currentUser != null;
  // }

  Future<User> getProfile() async {
    return await httpApiClient.getProfile();
  }

  // Future<String> getUsername() async {
  //   print("user_repository getUsername");
  //   return (await httpApiClient.currentUser()).username;
  // }

}

==> bytedesk_kefu-0.0.4.tar.gz: lib/repositories/user_repository.dart <==
import 'dart:async';
// import 'package:google_sign_in/google_sign_in.dart';
import 'package:bytedesk_kefu/model/codeResult.dart';
import 'package:bytedesk_kefu/model/jsonResult.dart';
import 'package:bytedesk_kefu/model/user.dart';
import 'package:bytedesk_kefu/http/bytedesk_http_api.dart';
import 'package:bytedesk_kefu/model/oauth.dart';
// import 'package:meta/meta.dart';

class UserRepository {
  final BytedeskHttpApi bytedeskHttpApi = BytedeskHttpApi();

  UserRepository();

  Future<OAuth> login(String username, String password) {
    print("login username $username, password $password");
    return bytedeskHttpApi.oauth(username, password);
  }

  Future<OAuth> smsOAuth(String mobile, String code) async {
    print("user_repository smsOAuth");
    return await bytedeskHttpApi.smsOAuth(mobile, code);
  }

  Future<JsonResult> register(String mobile, String password) async {
    print("user_repository register");
    return await bytedeskHttpApi.register(mobile, password);
  }

  Future<JsonResult> changePassword(String mobile, String password) async {
    print("user_repository change");
    return await bytedeskHttpApi.changePassword(mobile, password);
  }

  Future<CodeResult> requestCode(String mobile) async {
    print("user_repository requestCode");
    return await bytedeskHttpApi.requestCode(mobile);
  }

  Future<String> upload(String filePath) async {
    return await bytedeskHttpApi.upload(filePath);
  }

  Future<User> updateAvatar(String avatar) async {
    return await bytedeskHttpApi.updateAvatar(avatar);
  }

  Future<User> updateNickname(String nickname) async {
    return await bytedeskHttpApi.updateNickname(nickname);
  }

  Future<User> updateDescription(String description) async {
    return await bytedeskHttpApi.updateDescription(description);
  }

  Future<void> logout() async {
    print("user_repository logout");
    return Future.wait([bytedeskHttpApi.logout()]);
  }

  // Future<bool> isLogin() async {
  //   print("user_repository isSignedIn");
  //   // final currentUser = await BytedeskHttpApi.currentUser();
  //   // return currentUser != null;
  // }

  Future<User> getProfile() async {
    return await bytedeskHttpApi.getProfile();
  }

  // Future<String> getUsername() async {
  //   print("user_repository getUsername");
  //   return (await BytedeskHttpApi.currentUser()).username;
  // }

}
